@@ -1,6 +1,6 @@
 from .containers import ImportContainer, ExportContainer
 from .errors import ModelClassNotRegistered
-from .policy import DISCARD_OBJECT, ManyToManyImportAction, RelinkAction, BaseRelinkAction, ImportPolicy, ExportPolicy
+from .policy import ManyToManyImportAction, RelinkAction, BaseRelinkAction, ImportPolicy, ExportPolicy
 from .serializers import Exporter, ForeignKey, ReverseForeignKey, ManyToMany
 from .types import ID, Ref, Attachment, ObjectData, ContainerFormat
 
@@ -10,7 +10,6 @@ __all__ = [
 
     'ModelClassNotRegistered',
 
-    'DISCARD_OBJECT',
     'RelinkAction',
     'BaseRelinkAction',
     'ContainerFormat',
@@ -29,4 +28,4 @@ __all__ = [
     'ObjectData',
 ]
 
-__version__ = '0.0.7'
+__version__ = '0.0.8'
