@@ -9,10 +9,10 @@ from io import TextIOWrapper, BufferedReader
 from typing import Any, BinaryIO, Dict, Iterable, List, Optional, Set, Tuple, Type
 
 from ..errors import ModelClassNotRegistered
-from ..policy import DISCARD_OBJECT, ImportPolicy
+from ..policy import ImportPolicy
 from ..serializers import Exporter
 from ..types import ID, Ref, ObjectData, Attachment
-from .._util import UncloseableStream
+from .._util import UncloseableStream, get_model_options
 
 from .base import BaseContainer
 from ._yaml import get_yaml
@@ -212,7 +212,7 @@ class ImportContainer(BaseContainer):
             # Resolve all references
 
             for kind, objects in kind_map.items():
-                model_meta = ID.model_for_kind(kind)._meta.concrete_model._meta
+                model_meta = get_model_options(ID.model_for_kind(kind))
 
                 for obj in objects:
                     assert obj.fields is not None
@@ -287,7 +287,7 @@ class ImportContainer(BaseContainer):
                     logger.debug(f'Running {action} on {len(action_objects)} {kind} objects')
                     instances = action._execute(ID.model_for_kind(kind), action_objects, self.policy)
                     for obj, instance in zip(action_objects, instances):
-                        if instance is DISCARD_OBJECT:
+                        if instance is False:
                             self._discard_objects([obj], reason='due to relink policy')
                         else:
                             self.policy.post_object_import(instance)
